@@ -1,6 +1,5 @@
-/* Created by Ville-Petteri Makinen 2003-2010
-   Copyright (C) V-P Makinen
-   All rights reserved */
+/* Created by Ville-Petteri Makinen
+   email: ville.makinen@vipmak.net */
 
 #include "medusa.local.h"
 
@@ -11,12 +10,20 @@
 string
 medusa::string2safe(const std::string& orig, const mdsize maxlen) {
 
-  /* Replace characters. */  
+  /* Adjust length. */
   string s = orig;
-  for(mdsize i = 0; i < orig.size(); i++) {
-    char c = orig[i];
-    if(isalnum(c)) continue;
-    switch(c) {
+  if(s.size() > maxlen) {
+    s = s.substr(0, maxlen);
+    if(maxlen > 1) {
+      s[maxlen-1] = '.';
+      s[maxlen-2] = '.';
+    }
+  }
+
+  /* Replace characters. */
+  for(mdsize i = 0; i < s.size(); i++) {
+    if(isalnum(s[i])) continue;
+    switch(s[i]) {
     case '-': continue;
     case '+': continue;
     case '=': continue;
@@ -33,15 +40,6 @@ medusa::string2safe(const std::string& orig, const mdsize maxlen) {
     case ' ': continue;
     default: s[i] = '_';
     }
-  }
-  
-  /* Adjust length. */
-  if(s.length() > maxlen) {
-    s = s.substr(0, maxlen);
-    if(maxlen > 1) {
-      s[maxlen-1] = '.';
-      s[maxlen-2] = '.';
-    }
-  }
+  }  
   return s;
 }
